@@ -4,6 +4,7 @@ import argparse
 import logging
 
 from colorama import Fore, Style
+
 from nlab_inf_engine_scripts.InfEngineServer import InfEngineServer
 
 
@@ -46,18 +47,20 @@ def main():
         "--version", action="store_true", help=f"Print versions and exit."
     )
     group.add_argument(
-        "--dl-update", action="store",
+        "--dl-update",
+        action="store",
         nargs=1,
         default=None,
         metavar="DL_DATA_PATH",
-        help=f"Update DL data (binary or sources)."
+        help=f"Update DL data (binary or sources).",
     )
     group.add_argument(
-        "--dl-delete", action="store",
+        "--dl-delete",
+        action="store",
         nargs=1,
         default=None,
         metavar="DL_DATABASE_PATH",
-        help=f"Delete given DL data."
+        help=f"Delete given DL data.",
     )
     group.add_argument(
         "--dl-delete-all", action="store_true", help=f"Delete all DL data."
@@ -67,16 +70,21 @@ def main():
 
     root_path = args.root_path[0] if args.root_path else None
 
+    enable_logging = False
     if args.v:
         logging_level = logging.INFO
+        enable_logging = True
     elif args.vv:
         logging_level = logging.DEBUG
+        enable_logging = True
     else:
         logging_level = logging.ERROR
 
     print("\n    InfEngine Manager\n")
 
-    server = InfEngineServer(root_path=root_path, logging_level=logging_level)
+    server = InfEngineServer(
+        root_path=root_path, logging_level=logging_level, enable_logging=enable_logging
+    )
 
     try:
         if args.start:
